==> nextcloud-13.0.1.tgz: nextcloud/apps/theming/l10n/ja.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "プレビューを読込み中...",
    "Saved" : "保存済み",
    "Admin" : "管理者",
    "a safe home for all your data" : "あなたのデータを安全に保管するプラットフォーム",
    "The given name is too long" : "名前が長すぎます",
    "The given web address is too long" : "Webアドレスが長すぎます",
    "The given slogan is too long" : "スローガンが長すぎます",
    "The given color is invalid" : "無効な色です",
    "There is no error, the file uploaded with success" : "ファイルはエラーなくアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "Failed to write file to disk." : "ファイルをディスクに書き込めませんでした",
    "A PHP extension stopped the file upload." : "PHP拡張でファイルのアップロードが停止されています",
    "No file uploaded" : "ファイルがアップロードされていません",
    "Unsupported image type" : "サポートされていない画像形式です",
    "You are already using a custom theme" : "あなたは既にカスタムテーマを利用しています",
    "Theming" : "テーマ",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "テーマではあなたのインスタンスとサポートされたクライアントのルック＆フィールを簡単に変更できます。この変更は全てのユーザが対象となります。",
    "Name" : "名前",
    "Reset to default" : "デフォルトに戻す",
    "Web address" : "Webアドレス",
    "Web address https://…" : "Webアドレス https://...",
    "Slogan" : "スローガン",
    "Color" : "色",
    "Logo" : "ロゴ",
    "Upload new logo" : "新しいロゴをアップロード",
    "Login image" : "ログイン画像",
    "Upload new login background" : "新しいログイン背景画像をアップロード",
    "Remove background image" : "背景画像を削除",
    "reset to default" : "デフォルトに戻す"
},
"nplurals=1; plural=0;");

==> nextcloud-14.0.1.tgz: nextcloud/apps/theming/l10n/ja.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "プレビューを読み込み中...",
    "Saved" : "保存済み",
    "Admin" : "管理者",
    "a safe home for all your data" : "あなたのデータを安全に保管するプラットフォーム",
    "The given name is too long" : "名前が長すぎます",
    "The given web address is too long" : "Webアドレスが長すぎます",
    "The given slogan is too long" : "スローガンが長すぎます",
    "The given color is invalid" : "無効な色です",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "No file uploaded" : "ファイルがアップロードされていません",
    "Unsupported image type" : "サポートされていない画像形式です",
    "Theming" : "テーマ",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "テーマではあなたのインスタンスとサポートされたクライアントのルック＆フィールを簡単に変更できます。この変更はすべてのユーザーが対象となります。",
    "Name" : "名前",
    "Reset to default" : "デフォルトに戻す",
    "Web link" : "Webリンク",
    "Slogan" : "スローガン",
    "Color" : "色",
    "Logo" : "ロゴ",
    "Upload new logo" : "新しいロゴをアップロード",
    "Login image" : "ログイン画像",
    "Upload new login background" : "新しいログイン背景画像をアップロード",
    "Remove background image" : "背景画像を削除",
    "Legal notice link" : "法的通知のリンク",
    "Privacy policy link" : "プライバシーポリシーのリンク",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "アップロードしたロゴと色に基づいてfaviconを自動的に生成するには、SVG画像をサポートしたimagemagick PHP拡張をインストールしてください。",
    "You are already using a custom theme" : "すでにカスタムテーマを利用しています",
    "reset to default" : "デフォルトに戻す",
    "Web address" : "Webアドレス",
    "Web address https://…" : "Webアドレス https://...",
    "There is no error, the file uploaded with success" : "ファイルはエラーなくアップロードされました",
    "Failed to write file to disk." : "ファイルをディスクに書き込めませんでした",
    "A PHP extension stopped the file upload." : "PHP拡張でファイルのアップロードが停止されています"
},
"nplurals=1; plural=0;");
